#include "plot.h"

#include <QtDebug>

int step = 5;
int xOffset = 0;
int graphHeight = 300;
bool working = true;

Plot::Plot()
{
    x1=0;
    x2=0;
    y1=0;
    y2=0;

    graphicsView = new QGraphicsView;
    //graphicsView->setFixedSize(550,350);
    //graphicsView->horizontalScrollBar()->setHidden(true);
    graphicsView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
    graphicsView->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    graphicsView->verticalScrollBar()->setHidden(true);

    qsrand(QDateTime::currentDateTime().toTime_t());

    button = new QPushButton("Button");
    connect(button,SIGNAL(clicked()),this,SLOT(timerStopStart()));
    button->setText("Stop");

    drawTimer = new QTimer(this);
    connect(drawTimer,SIGNAL(timeout()),this,SLOT(on_timer()));

    QGridLayout *layout = new QGridLayout;
    layout->addWidget(graphicsView,0,0);
    layout->addWidget(button,1,0);
    QWidget *widget = new QWidget;
    widget->setLayout(layout);
    setCentralWidget(widget);

    scene = new QGraphicsScene();
    scene->setSceneRect(0,0,550,320);

    QPen rpen(Qt::red, 2.0);
    vLine = new QGraphicsLineItem;
    vLine->setLine(0,0,0,scene->height());
    vLine->setPen(rpen);
    scene->addItem(vLine);
    scene->setSceneRect(0,0,550,320);

    graphicsView->setScene(scene);
    //graphicsView->setDragMode(QGraphicsView::ScrollHandDrag);
    graphicsView->setRenderHint(QPainter::Antialiasing, true);
    graphicsView->viewport()->setMouseTracking(true);
    graphicsView->viewport()->installEventFilter(this);

    drawTimer->start(100);
}

bool Plot::eventFilter(QObject *obj, QEvent *event)
{
    if (event->type() == QEvent::MouseMove)
    {
        QMouseEvent *mEvent = static_cast<QMouseEvent*>(event);
        vLine->setPos(mEvent->pos().x()+graphicsView->horizontalScrollBar()->value(),0);
        return true;
    }
    else
        return false;
    return QMainWindow::eventFilter(obj, event);
}

void Plot::timerStopStart()
{
    if (working)
    {
        drawTimer->stop();
        button->setText("Start");
        working = false;
    }
    else
    {
        drawTimer->start();
        button->setText("Stop");
        working = true;
    }
}

void Plot::on_timer()
{
    // line drawing
    QPen pen(Qt::black, 2.0);
    x2 = x1+step;
    y2 = qrand()%graphHeight;
    scene->addLine(x1,y1,x2,y2,pen);
    //qDebug()<<x1<<y1<<x2<<y2;
    x1 = x2;
    y1 = y2;

    // debug information
    //qDebug()<<"xOffset ="<<xOffset;

    // scrolling
    if ((x2-xOffset)>graphicsView->width()/2)
    {
        graphicsView->horizontalScrollBar()->setValue(graphicsView->horizontalScrollBar()->value()+step);
        xOffset+=step;

        //start scroll at middle
        scene->setSceneRect(0,0,scene->width()+step,300);
    }

    if (scene->width()==x2)
        scene->setSceneRect(0,0,scene->width()+step,300);
}
